@@ -16,3 +16,12 @@ def convert_list(self, value):
     except:
         return None, 'Can not convert %r' % value 
 Option.conversions['list'] = convert_list
+
+def convert_bool(self, value):
+    try:
+        return eval(value), None
+    except:
+        return None, 'Can not convert %r' % value 
+Option.conversions['bool'] = convert_bool
+
+
