@@ -76,7 +76,7 @@ class ConfigurationService(object):
         filename = util.expand_full(filename)
         if not os.path.exists(filename):
             raise IOError('Mode file %s does not exist' % filename)
-        LOG.info('register model: %s' % filename)
+        LOG.debug('register model: %s' % filename)
         self.model_files.add(filename)
         self.reload()
 
@@ -87,13 +87,13 @@ class ConfigurationService(object):
         filename = util.expand_full(filename)
         if not os.path.exists(filename):
             raise IOError('Configuration file %s does not exist' % filename)
-        LOG.info('loading configuration: %s' % filename)
+        LOG.debug('loading configuration: %s' % filename)
         self.configuration_files.add(filename)
         self.reload()
 
         if self.watch and have_pyinotify:
             # watch path for events handled by notification mask.
-            LOG.info('watching %s' % filename)
+            LOG.debug('watching %s' % filename)
             self.notify_wm.add_watch(filename, self.notify_mask)
 
     @synchronized(lock)
