@@ -13,7 +13,8 @@ import os
 
 from zope.interface import Interface
 from zope.schema import TextLine 
-from service_hrs import HRSConfigurationService
+from services import CentralConfigurationService, \
+                     CentralConfigurationServiceSupervised
 
 class IModelDefinition(Interface):
     """ Used for defining a model"""
@@ -39,7 +40,8 @@ def registerModel(_context, model):
     model_cfg = os.path.join(context_dirname, model)
     if os.path.exists(model_cfg):
         model = model_cfg
-    HRSConfigurationService.registerModel(model)
+    CentralConfigurationService.registerModel(model)
+    CentralConfigurationServiceSupervised.registerModel(model)
 
 def registerConfiguration(_context, configuration):
     # str() because cfgparse.add_file performs an explicit check
@@ -48,5 +50,6 @@ def registerConfiguration(_context, configuration):
     possible_cfg = os.path.join(context_dirname, configuration)
     if os.path.exists(possible_cfg):
         configuration = possible_cfg
-    HRSConfigurationService.loadConfiguration(str(configuration))
 
+    CentralConfigurationService.loadConfiguration(str(configuration))
+    CentralConfigurationServiceSupervised.loadConfiguration(str(configuration))
